==> BestContato 1.0.1.zip: BestContato 1.0.1/contato/form.php <==
<?
session_start();

/******************************************************
**
**	Nome do Arquivo: form.php
**	Data de Criao: 01/05/2007
**	Autor: Thiago Felipe Festa - thiagofesta@gmail.com
**	ltima alterao:
**	Modificado por:
**
******************************************************/

// Inicio a sesso, pois estamos trabalhando com sesses.

// Aqui  a ao do formulrio, se clicar em enviar ele chama isto.
if( $_GET["validar"] == "form" ){

	// Texto digitado no campo imagem, e transformando tudo em mnsculo, caso queria que haja distino de maisculas e minsculas, s retire o strtoupper().
 	$txtImagem = strtoupper($_POST["txtImagem"]);
	
	// Caracteres que esto na imagem, tambm deixando tudo em minsulo.
	$valorImagem = strtoupper($_SESSION["autenticaIMG"]);
	
	// Verificando se o texto digitado, for igual aos caracteres que esto na imagem
	if( $txtImagem == $valorImagem ){
		echo "->";

        include ("enviar.php"); /* Se os dados esto corretos ento enviar o e-mail com os formulrio abaixo
                                   No esquea de Configurar o Enviar.php */


    } else {
		echo "Desculpa ". $_POST["Nome"] .", os caracteres digitados esto incorretos!";
	}

}

// Incluindo o imgSet.php que seta os valores da sesso.
require_once ("imgSet.php");	

?>
<!--
Notem que ali no <img src="imgGera.php">, eu chamo o arquivo imgGera.php...
estou adicionando ele, pois nele que est instnciada a classe imagem
-->

<!-- O Formulario foi desenvolvido utilizando no sistema de Captcha acima, por Arthur Bonora
www.arthurbonora.com.br
-->

<html>
<head>
<style type="text/css">
<!--
.Estilo3 {font-family: Geneva, Arial, Helvetica, sans-serif; font-size: 12; }
.Estilo4 {font-size: 12}
.Estilo5 {
	font-family: Geneva, Arial, Helvetica, sans-serif;
	font-size: 12px;
}
.Estilo10 {
	font-size: 9px;
	color: #333333;
}
.Estilo13 {
	font-size: 7px;
	color: #333333;
	font-family: Geneva, Arial, Helvetica, sans-serif;
}
-->
</style>
</head>
<body>

<form id="form1" name="frmImgValida" method="post" action="form.php?validar=form">
  <table width="30%" border="0" cellspacing="2">
    <tr>
      <td width="12%" class="Estilo5"><p class="Estilo3">Nome:</p></td>
      <td width="88%"><span class="Estilo4">
        <label>
        <input name="Nome" type="text" id="Nome" size="40" />
        </label>
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><span class="Estilo3">E-mail:</span></td>
      <td><span class="Estilo4">
        <input name="email" type="text" id="email" size="40" />
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><span class="Estilo3">Fone:</span></td>
      <td><span class="Estilo4">
        <input name="fone" type="text" id="fone" size="20" />
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><p class="Estilo3">Assunto:</p>
      </td>
      <td><label><span class="Estilo4">
      <input name="assunto" type="text" id="assunto" size="27" />
      </span></label></td>
    </tr>
    <tr>
      <td class="Estilo5"><p class="Estilo3">Mensagem:</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      </td>
      <td><span class="Estilo4">
        <textarea name="mensagem" cols="40" rows="10" id="mensagem"></textarea>
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><p class="Estilo5">&nbsp;</p>
      <p class="Estilo5">&Eacute; Voc&ecirc;? </p></td>
      <td><span class="Estilo4">
        <label>
        <input name="txtImagem" type="text" id="txtImagem" size="20" />
        </label>
      </span>
	  <img src="imgGera.php">
	  </td>
    </tr>
    <tr>
      <td><span class="Estilo4"></span></td>
      <td><div align="right"><span class="Estilo4">
      </span></div>        <span class="Estilo4"><label>
        </span>
      <div align="right"> <span class="Estilo10">
        <input type="submit" name="Submit" value="Enviar" />
      </span></div>
      <span class="Estilo10">
        </label>
        </span><span class="Estilo13"><a href="http://www.arthurbonora.com.br" target="_blank">Best Contato 1.0.1</a></span> </td>
    </tr>
  </table>
</form>

</body>
</html>

==> BestContato 1.0.2.zip: BestContato 1.0.2/contato/form.php <==
<?
session_start();

// Inicio a sesso, pois estamos trabalhando com sesses.

// Aqui  a ao do formulrio, se clicar em enviar ele chama isto.
if( $_GET["validar"] == "form" ){

	// Texto digitado no campo imagem, e transformando tudo em mnsculo, caso queria que haja distino de maisculas e minsculas, s retire o strtoupper().
 	$txtImagem = strtoupper($_POST["txtImagem"]);
	
	// Caracteres que esto na imagem, tambm deixando tudo em minsulo.
	$valorImagem = strtoupper($_SESSION["autenticaIMG"]);
	
	// Verificando se o texto digitado, for igual aos caracteres que esto na imagem
	if( $txtImagem == $valorImagem ){
		echo "->";

        include ("enviar.php"); /* Se os dados esto corretos ento enviar o e-mail com os formulrio abaixo
                                   No esquea de Configurar o Enviar.php */


    } else {
		echo "Desculpa ". $_POST["Nome"] .", os caracteres digitados esto incorretos!";
	}

}

// Incluindo o imgSet.php que seta os valores da sesso.
require_once ("imgSet.php");	

?>
<!--
Notem que ali no <img src="imgGera.php">, eu chamo o arquivo imgGera.php...
estou adicionando ele, pois nele que est instnciada a classe imagem
-->

<!-- O Formulario foi desenvolvido utilizando o sistema de Captcha acima, por Arthur Bonora
www.arthurbonora.com.br
-->

<html>
<head>
<style type="text/css">
<!--
.Estilo3 {font-family: Geneva, Arial, Helvetica, sans-serif; font-size: 12; }
.Estilo4 {font-size: 12}
.Estilo5 {
	font-family: Geneva, Arial, Helvetica, sans-serif;
	font-size: 12px;
}
.Estilo10 {
	font-size: 9px;
	color: #333333;
}
.Estilo14 {font-family: Geneva, Arial, Helvetica, sans-serif; font-size: 10px; }
-->
</style>
</head>
<body>

<form id="form1" name="frmImgValida" method="post" action="form.php?validar=form">
  <table width="30%" border="0" cellspacing="2">
    <tr>
      <td width="12%" class="Estilo5"><p class="Estilo3">Nome:</p></td>
      <td width="88%"><span class="Estilo4">
        <label>
        <input name="Nome" type="text" id="Nome" size="40" />
        </label>
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><span class="Estilo3">E-mail:</span></td>
      <td><span class="Estilo4">
        <input name="email" type="text" id="email" size="40" />
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><span class="Estilo3">Fone:</span></td>
      <td><span class="Estilo4">
        <input name="ddd" type="text" id="ddd" size="7" />
        <input name="fone" type="text" id="fone" size="20" />
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><p class="Estilo3">Assunto:</p>
      </td>
      <td><label><span class="Estilo4">
      <input name="assunto" type="text" id="assunto" size="28" />
      </span></label></td>
    </tr>
    <tr>
      <td class="Estilo5"><p class="Estilo3">Mensagem:</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      <p class="Estilo3">&nbsp;</p>
      </td>
      <td><span class="Estilo4">
        <textarea name="mensagem" cols="40" rows="10" id="mensagem"></textarea>
      </span></td>
    </tr>
    <tr>
      <td class="Estilo5"><p class="Estilo14">Digite os caracteres da imagem: </p>      </td>
      <td><span class="Estilo4">
        <label>
        <input name="txtImagem" type="text" id="txtImagem" size="20" />
        </label>
      </span>
	  <img src="imgGera.php">
	  </td>
    </tr>
    <tr>
      <td><span class="Estilo4"></span></td>
      <td><div align="right"><span class="Estilo10">
      <input type="submit" name="Submit" value="Enviar" />
      </span></div>        </td>
    </tr>
  </table>
</form>

</body>
</html>
